@@ -1,9 +1,9 @@
 package Math::Vector::Real::XS;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use strict;
-use warnings;
+local $^W;
 
 require XSLoader;
 XSLoader::load('Math::Vector::Real::XS', $VERSION);
@@ -32,7 +32,7 @@ it automatically.
 =head1 SUPPORT
 
 In order to report bugs you can send me and email to the address that
-appears below or use the CPAN RT bugtracking system available at
+appears below or use the CPAN RT bug-tracking system available at
 L<http://rt.cpan.org>.
 
 The source for the development version of the module is hosted at
@@ -41,11 +41,11 @@ GitHub: L<https://github.com/salva/p5-Math-Vector-Real-XS>.
 =head2 My wishlist
 
 If you like this module and you're feeling generous, take a look at my
-Amazon Wish List: L<http://amzn.com/w/1WU1P6IR5QZ42>
+wishlist: L<http://amzn.com/w/1WU1P6IR5QZ42>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2012 by Salvador Fandiño (sfandino@yahoo.com).
+Copyright (C) 2012, 2013 by Salvador FandiE<ntilde>o (sfandino@yahoo.com).
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.2 or,
